==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/BollingerBandsOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core";
import { Series } from "./Series";
import { List$1 } from "igniteui-react-core";
import { Number_$type, typeCast, runOn, markType, markDep, getEnumerator, Point_$type, fromEnum } from "igniteui-react-core";
import { CategoryFrame } from "./CategoryFrame";
import { SafeEnumerable } from "./SafeEnumerable";
import { TrendCalculators } from "igniteui-react-core";
import { AxisRange } from "./AxisRange";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core";
import { Polygon } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
/**
 * @hidden
 */
export let BollingerBandsOverlay = /*@__PURE__*/ (() => {
    class BollingerBandsOverlay extends FinancialOverlay {
        bj() {
            return new BollingerBandsOverlay();
        }
        constructor() {
            super();
            this.aa3 = 0;
            this.aa4 = 0;
            this.aa1 = new List$1(Number_$type, 0);
            this.aa2 = new List$1(Number_$type, 0);
            this.ab = BollingerBandsOverlay.$;
            this.w5 = new CategoryFrame(4);
            this.w7 = new CategoryFrame(4);
            this.w3 = new CategoryFrame(4);
        }
        q7(a, b, c, d) {
            if (this.yk().contains(b)) {
                this.aav = false;
            }
            super.q7(a, b, c, d);
            switch (b) {
                case BollingerBandsOverlay.$$p[1]:
                    this.aav = false;
                    this.rp(false);
                    break;
                case BollingerBandsOverlay.$$p[0]:
                    this.rp(false);
                    break;
            }
        }
        aaw() {
            this.aa1.clear();
            this.aa2.clear();
            let a = getEnumerator(TrendCalculators.e(new SafeEnumerable(this.yj), this.aa6));
            let b = getEnumerator(TrendCalculators.f(new SafeEnumerable(this.yj), this.aa6));
            this.aa4 = 1.7976931348623157E+308;
            this.aa3 = -1.7976931348623157E+308;
            let c = true;
            let d = true;
            let e = this.aa5;
            while (c || d) {
                if (a.moveNext()) {
                    this.aa1.add(a.current);
                }
                else {
                    c = false;
                }
                if (b.moveNext()) {
                    this.aa2.add(b.current);
                }
                else {
                    d = false;
                }
                if (c && d) {
                    this.aa4 = Math.min(this.aa4, a.current - b.current * e);
                    this.aa3 = Math.max(this.aa3, a.current + b.current * e);
                }
            }
            return true;
        }
        ay(a) {
            if (this.aa1 == null || this.aa2 == null || a == null || this.dm == null || a != this.xk) {
                return null;
            }
            let b = new AxisRange(this.aa4, this.aa3);
            return b;
        }
        z7(a, b) {
            super.z7(a, b);
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.w1;
            let g = this.xk;
            let h = new ScalerParams(0, c, d, f.ch, e);
            let i = new ScalerParams(0, c, d, g.ch, e);
            a.f.clear();
            a.n.clear();
            a.q.clear();
            let j = typeCast(ISortingAxis_$type, this.w1);
            if (j != null && j.i$b.count != this.dm.count) {
                return;
            }
            let k = 0;
            k = this.ys(c, d, e);
            if (!this.aav) {
                this.aav = this.aaw();
                if (this.xk != null) {
                    this.xk.c2(true);
                }
            }
            i.b = this.ix();
            let l = this.w1.en(2, h) - this.w1.en(1, h);
            for (let m = b.b0.c; m <= b.b0.d; ++m) {
                let n;
                if (j == null) {
                    n = b.b0.getBucket(m);
                }
                else {
                    let o = j.i$b._inner[m];
                    let p = j.i$d(o);
                    let q = this.aa1._inner[m];
                    let r = this.aa2._inner[m];
                    let s = q;
                    let t = r;
                    let u = p;
                    let v = 1;
                    while (m < b.b0.d) {
                        o = j.i$b._inner[m + 1];
                        u = j.i$d(o);
                        if (u - p > l) {
                            break;
                        }
                        m++;
                        s += this.aa1._inner[m];
                        t += this.aa2._inner[m];
                        v++;
                    }
                    s /= v;
                    t /= v;
                    let w = s - t * this.aa5;
                    let x = s;
                    let y = s + t * this.aa5;
                    let z = NaN;
                    if (!isNaN_(p)) {
                        z = this.w1.ek(p, h);
                    }
                    n = [z, w, x, y];
                }
                let aa = Math.max(1, l);
                if (!isNaN_(n[0]) && m * aa >= this.aax) {
                    if (this.w1 != null && typeCast(ISortingAxis_$type, this.w1) !== null) {
                        n[0] = n[0] + k;
                    }
                    else {
                        n[0] = f.ek(n[0], h) + k;
                    }
                    n[1] = g.ek(n[1], i);
                    n[2] = g.ek(n[2], i);
                    n[3] = g.ek(n[3], i);
                    a.f.add(n);
                }
            }
        }
        o4(a, b) {
            super.o4(a, b);
            let c = b;
            if (c != null) {
                c.b7();
            }
        }
        i4(a, b, c) {
            if (this.aa1 == null) {
                return super.i4(a, b, c);
            }
            let d = this.getEffectiveViewport1(this.cu);
            let e = this.ys(this.cu.by, this.cu.bx, d);
            let f = new ScalerParams(0, this.cu.by, this.cu.bx, this.w1.ch, d);
            f.c = this.da.wc;
            return this.i6(this.aa1, a, this.w1, f, e, runOn(this, this.yr), b, c);
        }
        j9(a, b) {
            if (this.aa1 == null) {
                return super.j9(a, b);
            }
            return this.ka(a, b, this.w1, runOn(this, this.yr), this.aa1);
        }
        j7(a, b) {
            if (this.aa1 == null) {
                return super.j7(a, b);
            }
            return this.j8(a, b, this.w1, runOn(this, this.yr), this.aa1);
        }
        hd(a, b, c) {
            let d = super.hd(a, b, c);
            if (!this.ya(this.yk())) {
                d = false;
            }
            return d;
        }
        z9(a, b) {
            super.z9(a, b);
            let c = typeCast(BollingerBandsOverlayView.$, b);
            let d = this.getEffectiveViewport1(b);
            if (b.b3(a)) {
                c.b7();
                let e = a.f.count;
                let f = (g) => a.f._inner[g][0];
                let g = (h) => a.f._inner[e - 1 - h][0];
                let h = (i) => a.f._inner[i][1];
                let i = (j) => a.f._inner[j][2];
                let j = (k) => a.f._inner[e - 1 - k][3];
                c.b8(e, f, g, h, i, j);
                b.b5(a);
            }
            this.xa.a2(this, this.x9(), runOn(this, this.wt), this.yy(b), this.y0(b));
            let k = false;
            let l = this.xa.b;
            let m = a.f;
            let n = this.dm.count;
            if (l != null) {
                k = true;
            }
            if (k) {
                let o = new ScalerParams(0, b.by, b.bx, this.w1.ch, d);
                this.z6(m, -1, n, this.w1, o, b.q, -1);
            }
            let p = c.cf;
            let q = c.cg;
            let r = c.ch;
            let s = c.ca;
            this.xa.ad(q, true, false, true, true);
            this.xa.an = null;
            this.xa.am = null;
            this.xa.ad(p, true, false, false, true);
            this.xa.ad(r, true, false, false, true);
            this.xa.ad(s, false, true, false, false);
            s._opacity = this.xa.j * this.h8;
        }
        cr() {
            return new BollingerBandsOverlayView(this);
        }
        qz(a) {
            super.qz(a);
            this.aa0 = typeCast(BollingerBandsOverlayView.$, a);
        }
        y1() {
            return 3;
        }
        ix() {
            return Series.iz(this.aa1, null);
        }
    }
    BollingerBandsOverlay.$t = /*@__PURE__*/ markType(BollingerBandsOverlay, 'BollingerBandsOverlay', FinancialOverlay.$);
    BollingerBandsOverlay.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, BollingerBandsOverlay, 'raisePropertyChanged', ['Multiplier:aa5:aa9', [1, 2], 'Period:aa6:aba', [1, 14]]);
    return BollingerBandsOverlay;
})();
/**
 * @hidden
 */
export let BollingerBandsBucketCalculator = /*@__PURE__*/ (() => {
    class BollingerBandsBucketCalculator extends FinancialBucketCalculator {
        constructor(a) {
            super(a);
            this.f = null;
            this.f = a;
        }
        getBucket(a) {
            let b = a * this.b;
            let c = Math.min(b + this.b - 1, this.a.b2.dm.count - 1);
            if (b <= c) {
                let d = this.f.b6.aa5;
                let e = 0;
                let f = 0;
                let g = 0;
                for (let h = b; h <= c; ++h) {
                    if (!isNaN_(this.f.b6.aa1._inner[h]) && !isNaN_(this.f.b6.aa2._inner[h])) {
                        e += this.f.b6.aa1._inner[h];
                        f += this.f.b6.aa2._inner[h];
                        ++g;
                    }
                }
                if (g > 0) {
                    e = e / g;
                    f = f / g;
                    return [0.5 * (b + c), e - f * d, e, e + f * d];
                }
            }
            return [NaN, NaN, NaN, NaN];
        }
    }
    BollingerBandsBucketCalculator.$t = /*@__PURE__*/ markType(BollingerBandsBucketCalculator, 'BollingerBandsBucketCalculator', FinancialBucketCalculator.$);
    return BollingerBandsBucketCalculator;
})();
/**
 * @hidden
 */
export let BollingerBandsOverlayView = /*@__PURE__*/ (() => {
    class BollingerBandsOverlayView extends FinancialSeriesView {
        constructor(a) {
            super(a);
            this.b6 = null;
            this.cb = new Polygon();
            this.ci = new Polyline();
            this.cj = new Polyline();
            this.ck = new Polyline();
            this.b9 = new Polygon();
            this.cc = new Polyline();
            this.cd = new Polyline();
            this.ce = new Polyline();
            this.b6 = a;
        }
        au() {
            super.au();
            if (!this.q) {
            }
        }
        b1() {
            return new BollingerBandsBucketCalculator(this);
        }
        b8(a, b, c, d, e, f) {
            for (let g of fromEnum(Flattener.d(a, b, d, this.e.ic))) {
                this.cb.an.add({ $type: Point_$type, x: b(g), y: d(g) });
                this.ci.an.add({ $type: Point_$type, x: b(g), y: d(g) });
            }
            for (let h of fromEnum(Flattener.d(a, b, e, this.e.ic))) {
                this.cj.an.add({ $type: Point_$type, x: b(h), y: e(h) });
            }
            for (let i of fromEnum(Flattener.d(a, c, f, this.e.ic))) {
                this.cb.an.add({ $type: Point_$type, x: c(i), y: f(i) });
                this.ck.an.add({ $type: Point_$type, x: c(i), y: f(i) });
            }
            this.as();
        }
        b7() {
            this.cb.an.clear();
            this.ci.an.clear();
            this.cj.an.clear();
            this.ck.an.clear();
            this.as();
        }
        get ca() {
            return this.cb;
        }
        get cf() {
            return this.ci;
        }
        get cg() {
            return this.cj;
        }
        get ch() {
            return this.ck;
        }
        be() {
            super.be();
            this.b9.an = this.cb.an;
            this.cc.an = this.ci.an;
            this.cd.an = this.cj.an;
            this.ce.an = this.ck.an;
            let a = this.br();
            this.b9._fill = a;
            this.b9._opacity = 1;
            this.cc._stroke = a;
            this.cc.ad = this.e.id + 3;
            this.cd._stroke = a;
            this.cd.ad = this.e.id + 3;
            this.ce._stroke = a;
            this.ce.ad = this.e.id + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.u(this.b9);
                    a.v(this.cc);
                    a.v(this.cd);
                    a.v(this.ce);
                }
                else {
                    a.u(this.cb);
                    a.v(this.ci);
                    a.v(this.cj);
                    a.v(this.ck);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.bc.exportPolygonData(a, this.cb, "FillShape", ["Fill"]);
            this.e.bc.exportPolylineData(a, this.ci, "BottomLine", ["Lower", "Main"]);
            this.e.bc.exportPolylineData(a, this.cj, "CentralLine", ["Central"]);
            this.e.bc.exportPolylineData(a, this.ck, "TopLine", ["Upper"]);
        }
    }
    BollingerBandsOverlayView.$t = /*@__PURE__*/ markType(BollingerBandsOverlayView, 'BollingerBandsOverlayView', FinancialSeriesView.$);
    return BollingerBandsOverlayView;
})();

==> igniteui-react-charts-18.7.5-beta.0.tgz: package/esm2015/lib/BollingerBandsOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core";
import { Series } from "./Series";
import { List$1 } from "igniteui-react-core";
import { Number_$type, typeCast, runOn, markType, markDep, getEnumerator, Point_$type, fromEnum } from "igniteui-react-core";
import { CategoryFrame } from "./CategoryFrame";
import { SafeEnumerable } from "./SafeEnumerable";
import { TrendCalculators } from "igniteui-react-core";
import { AxisRange } from "./AxisRange";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core";
import { Polygon } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
/**
 * @hidden
 */
export let BollingerBandsOverlay = /*@__PURE__*/ (() => {
    class BollingerBandsOverlay extends FinancialOverlay {
        bj() {
            return new BollingerBandsOverlay();
        }
        constructor() {
            super();
            this.aa6 = 0;
            this.aa7 = 0;
            this.aa4 = new List$1(Number_$type, 0);
            this.aa5 = new List$1(Number_$type, 0);
            this.ab = BollingerBandsOverlay.$;
            this.w8 = new CategoryFrame(4);
            this.xa = new CategoryFrame(4);
            this.w6 = new CategoryFrame(4);
        }
        q7(a, b, c, d) {
            if (this.yn().contains(b)) {
                this.aay = false;
            }
            super.q7(a, b, c, d);
            switch (b) {
                case BollingerBandsOverlay.$$p[1]:
                    this.aay = false;
                    this.rp(false);
                    break;
                case BollingerBandsOverlay.$$p[0]:
                    this.rp(false);
                    break;
            }
        }
        aaz() {
            this.aa4.clear();
            this.aa5.clear();
            let a = getEnumerator(TrendCalculators.e(new SafeEnumerable(this.ym), this.aa9));
            let b = getEnumerator(TrendCalculators.f(new SafeEnumerable(this.ym), this.aa9));
            this.aa7 = 1.7976931348623157E+308;
            this.aa6 = -1.7976931348623157E+308;
            let c = true;
            let d = true;
            let e = this.aa8;
            while (c || d) {
                if (a.moveNext()) {
                    this.aa4.add(a.current);
                }
                else {
                    c = false;
                }
                if (b.moveNext()) {
                    this.aa5.add(b.current);
                }
                else {
                    d = false;
                }
                if (c && d) {
                    this.aa7 = Math.min(this.aa7, a.current - b.current * e);
                    this.aa6 = Math.max(this.aa6, a.current + b.current * e);
                }
            }
            return true;
        }
        ay(a) {
            if (this.aa4 == null || this.aa5 == null || a == null || this.dn == null || a != this.xn) {
                return null;
            }
            let b = new AxisRange(this.aa7, this.aa6);
            return b;
        }
        aaa(a, b) {
            super.aaa(a, b);
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.w4;
            let g = this.xn;
            let h = new ScalerParams(0, c, d, f.ch, e);
            let i = new ScalerParams(0, c, d, g.ch, e);
            a.f.clear();
            a.n.clear();
            a.q.clear();
            let j = typeCast(ISortingAxis_$type, this.w4);
            if (j != null && j.i$b.count != this.dn.count) {
                return;
            }
            let k = 0;
            k = this.yv(c, d, e);
            if (!this.aay) {
                this.aay = this.aaz();
                if (this.xn != null) {
                    this.xn.c2(true);
                }
            }
            i.b = this.iy();
            let l = this.w4.eo(2, h) - this.w4.eo(1, h);
            for (let m = b.b0.c; m <= b.b0.d; ++m) {
                let n;
                if (j == null) {
                    n = b.b0.getBucket(m);
                }
                else {
                    let o = j.i$b._inner[m];
                    let p = j.i$d(o);
                    let q = this.aa4._inner[m];
                    let r = this.aa5._inner[m];
                    let s = q;
                    let t = r;
                    let u = p;
                    let v = 1;
                    while (m < b.b0.d) {
                        o = j.i$b._inner[m + 1];
                        u = j.i$d(o);
                        if (u - p > l) {
                            break;
                        }
                        m++;
                        s += this.aa4._inner[m];
                        t += this.aa5._inner[m];
                        v++;
                    }
                    s /= v;
                    t /= v;
                    let w = s - t * this.aa8;
                    let x = s;
                    let y = s + t * this.aa8;
                    let z = NaN;
                    if (!isNaN_(p)) {
                        z = this.w4.el(p, h);
                    }
                    n = [z, w, x, y];
                }
                let aa = Math.max(1, l);
                if (!isNaN_(n[0]) && m * aa >= this.aa0) {
                    if (this.w4 != null && typeCast(ISortingAxis_$type, this.w4) !== null) {
                        n[0] = n[0] + k;
                    }
                    else {
                        n[0] = f.el(n[0], h) + k;
                    }
                    n[1] = g.el(n[1], i);
                    n[2] = g.el(n[2], i);
                    n[3] = g.el(n[3], i);
                    a.f.add(n);
                }
            }
        }
        o5(a, b) {
            super.o5(a, b);
            let c = b;
            if (c != null) {
                c.b7();
            }
        }
        i5(a, b, c) {
            if (this.aa4 == null) {
                return super.i5(a, b, c);
            }
            let d = this.getEffectiveViewport1(this.cv);
            let e = this.yv(this.cv.by, this.cv.bx, d);
            let f = new ScalerParams(0, this.cv.by, this.cv.bx, this.w4.ch, d);
            f.c = this.db.wj;
            return this.i7(this.aa4, a, this.w4, f, e, runOn(this, this.yu), b, c);
        }
        ka(a, b) {
            if (this.aa4 == null) {
                return super.ka(a, b);
            }
            return this.kb(a, b, this.w4, runOn(this, this.yu), this.aa4);
        }
        j8(a, b) {
            if (this.aa4 == null) {
                return super.j8(a, b);
            }
            return this.j9(a, b, this.w4, runOn(this, this.yu), this.aa4);
        }
        he(a, b, c) {
            let d = super.he(a, b, c);
            if (!this.yd(this.yn())) {
                d = false;
            }
            return d;
        }
        aac(a, b) {
            super.aac(a, b);
            let c = typeCast(BollingerBandsOverlayView.$, b);
            let d = this.getEffectiveViewport1(b);
            if (b.b3(a)) {
                c.b7();
                let e = a.f.count;
                let f = (g) => a.f._inner[g][0];
                let g = (h) => a.f._inner[e - 1 - h][0];
                let h = (i) => a.f._inner[i][1];
                let i = (j) => a.f._inner[j][2];
                let j = (k) => a.f._inner[e - 1 - k][3];
                c.b8(e, f, g, h, i, j);
                b.b5(a);
            }
            this.xd.a2(this, this.yc(), runOn(this, this.ww), this.y1(b), this.y3(b));
            let k = false;
            let l = this.xd.b;
            let m = a.f;
            let n = this.dn.count;
            if (l != null) {
                k = true;
            }
            if (k) {
                let o = new ScalerParams(0, b.by, b.bx, this.w4.ch, d);
                this.z9(m, -1, n, this.w4, o, b.q, -1);
            }
            let p = c.cf;
            let q = c.cg;
            let r = c.ch;
            let s = c.ca;
            this.xd.ad(q, true, false, true, true);
            this.xd.an = null;
            this.xd.am = null;
            this.xd.ad(p, true, false, false, true);
            this.xd.ad(r, true, false, false, true);
            this.xd.ad(s, false, true, false, false);
            s._opacity = this.xd.j * this.h9;
        }
        cs() {
            return new BollingerBandsOverlayView(this);
        }
        qz(a) {
            super.qz(a);
            this.aa3 = typeCast(BollingerBandsOverlayView.$, a);
        }
        y4() {
            return 3;
        }
        iy() {
            return Series.i0(this.aa4, null);
        }
    }
    BollingerBandsOverlay.$t = /*@__PURE__*/ markType(BollingerBandsOverlay, 'BollingerBandsOverlay', FinancialOverlay.$);
    BollingerBandsOverlay.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, BollingerBandsOverlay, 'raisePropertyChanged', ['Multiplier:aa8:abc', [1, 2], 'Period:aa9:abd', [1, 14]]);
    return BollingerBandsOverlay;
})();
/**
 * @hidden
 */
export let BollingerBandsBucketCalculator = /*@__PURE__*/ (() => {
    class BollingerBandsBucketCalculator extends FinancialBucketCalculator {
        constructor(a) {
            super(a);
            this.f = null;
            this.f = a;
        }
        getBucket(a) {
            let b = a * this.b;
            let c = Math.min(b + this.b - 1, this.a.b2.dn.count - 1);
            if (b <= c) {
                let d = this.f.b6.aa8;
                let e = 0;
                let f = 0;
                let g = 0;
                for (let h = b; h <= c; ++h) {
                    if (!isNaN_(this.f.b6.aa4._inner[h]) && !isNaN_(this.f.b6.aa5._inner[h])) {
                        e += this.f.b6.aa4._inner[h];
                        f += this.f.b6.aa5._inner[h];
                        ++g;
                    }
                }
                if (g > 0) {
                    e = e / g;
                    f = f / g;
                    return [0.5 * (b + c), e - f * d, e, e + f * d];
                }
            }
            return [NaN, NaN, NaN, NaN];
        }
    }
    BollingerBandsBucketCalculator.$t = /*@__PURE__*/ markType(BollingerBandsBucketCalculator, 'BollingerBandsBucketCalculator', FinancialBucketCalculator.$);
    return BollingerBandsBucketCalculator;
})();
/**
 * @hidden
 */
export let BollingerBandsOverlayView = /*@__PURE__*/ (() => {
    class BollingerBandsOverlayView extends FinancialSeriesView {
        constructor(a) {
            super(a);
            this.b6 = null;
            this.cb = new Polygon();
            this.ci = new Polyline();
            this.cj = new Polyline();
            this.ck = new Polyline();
            this.b9 = new Polygon();
            this.cc = new Polyline();
            this.cd = new Polyline();
            this.ce = new Polyline();
            this.b6 = a;
        }
        au() {
            super.au();
            if (!this.q) {
            }
        }
        b1() {
            return new BollingerBandsBucketCalculator(this);
        }
        b8(a, b, c, d, e, f) {
            for (let g of fromEnum(Flattener.d(a, b, d, this.e.id))) {
                this.cb.an.add({ $type: Point_$type, x: b(g), y: d(g) });
                this.ci.an.add({ $type: Point_$type, x: b(g), y: d(g) });
            }
            for (let h of fromEnum(Flattener.d(a, b, e, this.e.id))) {
                this.cj.an.add({ $type: Point_$type, x: b(h), y: e(h) });
            }
            for (let i of fromEnum(Flattener.d(a, c, f, this.e.id))) {
                this.cb.an.add({ $type: Point_$type, x: c(i), y: f(i) });
                this.ck.an.add({ $type: Point_$type, x: c(i), y: f(i) });
            }
            this.as();
        }
        b7() {
            this.cb.an.clear();
            this.ci.an.clear();
            this.cj.an.clear();
            this.ck.an.clear();
            this.as();
        }
        get ca() {
            return this.cb;
        }
        get cf() {
            return this.ci;
        }
        get cg() {
            return this.cj;
        }
        get ch() {
            return this.ck;
        }
        be() {
            super.be();
            this.b9.an = this.cb.an;
            this.cc.an = this.ci.an;
            this.cd.an = this.cj.an;
            this.ce.an = this.ck.an;
            let a = this.br();
            this.b9._fill = a;
            this.b9._opacity = 1;
            this.cc._stroke = a;
            this.cc.ad = this.e.ie + 3;
            this.cd._stroke = a;
            this.cd.ad = this.e.ie + 3;
            this.ce._stroke = a;
            this.ce.ad = this.e.ie + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.u(this.b9);
                    a.v(this.cc);
                    a.v(this.cd);
                    a.v(this.ce);
                }
                else {
                    a.u(this.cb);
                    a.v(this.ci);
                    a.v(this.cj);
                    a.v(this.ck);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.bc.exportPolygonData(a, this.cb, "FillShape", ["Fill"]);
            this.e.bc.exportPolylineData(a, this.ci, "BottomLine", ["Lower", "Main"]);
            this.e.bc.exportPolylineData(a, this.cj, "CentralLine", ["Central"]);
            this.e.bc.exportPolylineData(a, this.ck, "TopLine", ["Upper"]);
        }
    }
    BollingerBandsOverlayView.$t = /*@__PURE__*/ markType(BollingerBandsOverlayView, 'BollingerBandsOverlayView', FinancialSeriesView.$);
    return BollingerBandsOverlayView;
})();
